@@ -63,7 +63,12 @@ pub async fn get_individual_from_db(uri: &str, user_uri: &str, db: &AStorage, az
     Ok((Individual::default(), ResultCode::UnprocessableEntity))
 }
 
-pub async fn check_ticket(w_ticket_id: &Option<String>, ticket_cache: &TicketCache, db: &AStorage) -> io::Result<(ResultCode, Option<String>)> {
+pub async fn check_ticket(
+    w_ticket_id: &Option<String>,
+    ticket_cache: &TicketCache,
+    addr: Option<std::net::SocketAddr>,
+    db: &AStorage,
+) -> io::Result<(ResultCode, Option<String>)> {
     if w_ticket_id.is_none() {
         return Ok((ResultCode::Ok, Some("cfg:Guest".to_owned())));
     }
@@ -75,7 +80,7 @@ pub async fn check_ticket(w_ticket_id: &Option<String>, ticket_cache: &TicketCac
 
     if let Some(cached_ticket) = ticket_cache.read.get(&ticket_id.to_owned()) {
         if let Some(t) = cached_ticket.get_one() {
-            if t.is_ticket_valid() != ResultCode::Ok {
+            if t.is_ticket_valid(addr) != ResultCode::Ok {
                 return Ok((ResultCode::TicketNotFound, None));
             }
             Ok((ResultCode::Ok, Some(t.user_uri.clone())))
@@ -106,7 +111,7 @@ pub async fn check_ticket(w_ticket_id: &Option<String>, ticket_cache: &TicketCac
         if ticket_obj.result != ResultCode::Ok {
             return Ok((ResultCode::TicketNotFound, None));
         }
-        if ticket_obj.is_ticket_valid() != ResultCode::Ok {
+        if ticket_obj.is_ticket_valid(addr) != ResultCode::Ok {
             return Ok((ResultCode::TicketNotFound, None));
         }
 
